auth_ticket: A Function for getting Quickbase Authentication Tickets

Description Usage Arguments

View source: R/auth_ticket.r

Description

This Function uses GET to return a response from quickbase with the Quickbase Ticket ID located within the contents of the html response

Usage

1
auth_ticket(ticket_handle)

Arguments

ticket_handle

A handle object returned by the auth_ticket_handle() function


mre011/Rqbase documentation built on May 23, 2019, 7:16 a.m.