db_ids: GET Quickbase db/app/table names and unique IDs

Description Usage Arguments

View source: R/db_ids.R

Description

This function sends a request to quickbase to return a response with the db names and ids which the user has access to. The response in returned as html which is then parsed and returned as a dataframe.

Usage

1
db_ids(URL, qb_ticket_id)

Arguments

URL

A url for Quickbase company domain

qb_ticket_id

A valid quickbase authentication ticket


mre011/Rqbase documentation built on May 23, 2019, 7:16 a.m.