qb_do_query: GET Request for tablular data within quickbase app.

Description Usage Arguments

View source: R/qb_do_query.r

Description

This function sends a request to quickbase to return a response with the app data. The response in returned as html which is then parsed and returned as a html page which then can be parsed using qb_parse

Usage

1
qb_do_query(URL, db_id, qb_ticket_id, app_token)

Arguments

URL

A url for Quickbase company domain

qb_ticket_id

A valid quickbase authentication ticket

app_token

A valid quickbase app token


mre011/Rqbase documentation built on May 23, 2019, 7:16 a.m.