This Function uses GET to return a response from quickbase with the Quickbase Ticket ID located within the contents of the html response
1 | auth_ticket(ticket_handle)
|
ticket_handle |
A handle object returned by the auth_ticket_handle() function |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.