This function sends a request to quickbase to return a response with the db names and ids which the user has access to. The response in returned as html which is then parsed and returned as a dataframe.
1 | db_ids(URL, qb_ticket_id)
|
URL |
A url for Quickbase company domain |
qb_ticket_id |
A valid quickbase authentication ticket |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.