This function sends a request to quickbase to return a response with the app data. The response in returned as html which is then parsed and returned as a html page which then can be parsed using qb_parse
1 | qb_do_query(URL, db_id, qb_ticket_id, app_token)
|
URL |
A url for Quickbase company domain |
qb_ticket_id |
A valid quickbase authentication ticket |
app_token |
A valid quickbase app token |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.